########
# Provided by mcs2 magic
########

variable "tags" {
  type        = map(string)
  description = "Tags for all resources"
}

# Unused, having it left out results in a warning in the logs that can safely be ignored.
# Uncommenting and not using causes linting issues.
#variable "default_env_vars" {
#  description = "A mapping of variables that are added by default from mcs2. The primary purpose is for metrics."
#  type        = map(string)
#  default     = {}
#}

########
# User provided
########

#### These come from the config map and script magic

variable "processing_bucket_name" {
  type        = string
  description = "Name of the S3 bucket that has all of the jars, wheels, libs, in-flight and log data are located"
}

variable "job_dlq_arn" {
  type        = string
  description = "ARN of the SQS DLQ for failed jobs."
}

variable "event_bridge_dlq_arn" {
  type        = string
  description = "ARN of the SQS DLQ for event bridge. This is the DLQ for the job DLQ and is used if even bridge issues occur."
}

variable "name_prefix" {
  type        = string
  description = "Naming prefix to make mcs2 happy."
}

variable "iam_role_name" {
  type        = string
  description = "Name of the IAM role used by the Glue jobs."
}

variable "mcs2_env" {
  type        = string
  description = "Name of the mosaic 2 environment, e.g. kcdev01, prd5use1."
}

#### These come from the docker image

variable "default_sade_uds_alerts_lib_version" {
  type        = string
  description = "The default version of the library to use. This value is used unless one is provided by the config."
}

variable "hudi_extensions_lib_version" {
  type        = string
  description = "The version of the Hudi extensions library to use."
}

variable "spark_ingress_lib_version" {
  type        = string
  description = "The version of the spark ingress library to use."
}

variable "hudi_jars" {
  type        = string
  description = "Comma-separated list of Hudi jar names."
}

#### These come from the helm chart

# Expected items:
#   * SRC_ACCOUNT_ID
#   * TABLE_NAME
#   * ENV_NAME: dev, stage, prod
#   * DEFAULT_SADE_ALERTS_FILTER_LIB_VERSION
variable "extra_environment" {
  type        = map(string)
  description = "Environment variables coming from custom helm chart."
}

#### This is used in event-bridge.tf
locals {
  jobs = ["sade-uds-alerts"]
}
