resource "aws_glue_workflow" "table_services_deletion" {
  name = "${var.name_prefix}-deletion-workflow"
  tags = var.tags
}

resource "aws_glue_trigger" "delete_partition" {
  name          = "${var.name_prefix}-delete-partition"
  tags          = var.tags
  type          = "SCHEDULED"
  schedule      = "cron(05 0/1 * * ? *)" # Run every hour at 5th min
  workflow_name = aws_glue_workflow.table_services_deletion.name
  # On-demand so disabled isn't an option
  enabled = true

  actions {
    job_name = aws_glue_job.sade_uds_alerts_delete_partitions.name
  }
}

resource "aws_glue_trigger" "cleaning" {
  name          = "${var.name_prefix}-cleaning"
  tags          = var.tags
  type          = "CONDITIONAL"
  workflow_name = aws_glue_workflow.table_services_deletion.name

  predicate {
    conditions {
      job_name         = aws_glue_job.sade_uds_alerts_delete_partitions.name
      state            = "SUCCEEDED"
      logical_operator = "EQUALS"
    }
    logical = "AND"
  }

  actions {
    job_name = aws_glue_job.sade_uds_alerts_cleaning.name
  }
}
